@@ -5,31 +5,31 @@
 #' 
 #' A vector of probabilities to be used in Quantile Least Mahalanobis Distance estimation (\code{\link{QLMDe}}). 
 #' 
-#' @param from \code{\link[base]{numeric}} scalar, minimum of the equidistant (in probability or quantile) probabilities.  Default \code{.05}.
+#' @param from \link[base]{numeric} scalar, minimum of the equidistant (in probability or quantile) probabilities.  Default \code{.05}.
 #' 
-#' @param to \code{\link[base]{numeric}} scalar, maximum of the equidistant (in probability or quantile) probabilities.  Default \code{.95}.
+#' @param to \link[base]{numeric} scalar, maximum of the equidistant (in probability or quantile) probabilities.  Default \code{.95}.
 #' 
-#' @param length.out non-negative \code{\link[base]{integer}} scalar, the number of the equidistant (in probability or quantile) probabilities. 
+#' @param length.out non-negative \link[base]{integer} scalar, the number of the equidistant (in probability or quantile) probabilities. 
 #' 
-#' @param equidistant \code{\link[base]{character}} scalar.
+#' @param equidistant \link[base]{character} scalar.
 #' If \code{'prob'} (default), then the probabilities are equidistant.  
-#' If \code{'quantile'}, then the quantiles (of the observations \code{obs}) corresponding to the probabilities are equidistant.
+#' If \code{'quantile'}, then the quantiles (of the observations \code{x}) corresponding to the probabilities are equidistant.
 #' 
-#' @param extra \code{\link[base]{numeric}} vector of \emph{additional} probabilities, default \code{c(.005, .01, .02, .03, .97, .98, .99, .995)}.
+#' @param extra \link[base]{numeric} vector of \emph{additional} probabilities, default \code{c(.005, .01, .02, .03, .97, .98, .99, .995)}.
 #' 
-#' @param obs \code{\link[base]{numeric}} vector of observations, only used when \code{equidistant = 'quantile'}.
+#' @param x \link[base]{numeric} vector of observations, only used when \code{equidistant = 'quantile'}.
 #' 
 #' @details
 #' 
-#' The default arguments of \code{\link{QLMDp}} gives the probabilities of 
+#' The default arguments of \link{QLMDp} returns the probabilities of 
 #' \code{c(.005, .01, .02, .03, seq.int(.05, .95, length.out = 15L), .97, .98, .99, .995)}.
 #' 
 #' @return 
 #' 
-#' A \code{\link[base]{numeric}} vector of probabilities to be supplied to parameter \code{p} of 
-#' Quantile Least Mahalanobis Distance estimation (\code{\link{QLMDe}}).
+#' A \link[base]{numeric} vector of probabilities to be supplied to parameter \code{p} of 
+#' Quantile Least Mahalanobis Distance \link{QLMDe} estimation).
 #' In practice, the length of this probability vector \code{p} 
-#' must be equal or larger than the number of parameters in the distribution model to be estimated in \code{\link{QLMDe}}.
+#' must be equal or larger than the number of parameters in the distribution model to be estimated.
 #' 
 #' @examples 
 #' 
@@ -43,7 +43,7 @@
 #' autoplot(d2, v = setNames(qfmx(p1, dist = d2), nm = sprintf('%.1f%%', 1e2*p1)))
 #' autoplot(d2, v = quantile(x2, probs = p1, digits = 3L)) + p_hist
 #' 
-#' (p2 = QLMDp(equidistant = 'quantile', obs = x2)) # equidistnat in quantiles
+#' (p2 = QLMDp(equidistant = 'quantile', x = x2)) # equidistnat in quantiles
 #' autoplot(d2, v = quantile(x2, probs = p2, digits = 3L)) + p_hist
 #' 
 #' 
@@ -51,7 +51,7 @@
 QLMDp <- function(
   from = .05, to = .95, length.out = 15L, equidistant = c('prob', 'quantile'),
   extra = c(.005, .01, .02, .03, .97, .98, .99, .995),
-  obs
+  x
 ) {
   
   if (!is.double(from) || length(from) != 1L || is.na(from) || from <= 0) stop('`from` must be numeric >0')
@@ -65,9 +65,9 @@ QLMDp <- function(
       seq.int(from = from, to = to, length.out = length.out)
     }, quantile = {
       #cat('Equidistant in quantile; ')
-      if (missing(obs)) stop('Must have `obs`')
-      qlim <- quantile(obs, probs = c(from, to)) # not compute intensive
-      ecdf(obs)(seq.int(from = qlim[1L], to = qlim[2L], length.out = length.out))
+      if (missing(x)) stop('Must have `x`')
+      qlim <- quantile(x, probs = c(from, to)) # not compute intensive
+      ecdf(x)(seq.int(from = qlim[1L], to = qlim[2L], length.out = length.out))
     }))
   }
   if (!length(p)) stop('len-0 p, do not allow')
